from __future__ import absolute_import

# flake8: noqa

# import apis into api package
from pypureclient.pure1.api.alerts_api import AlertsApi
from pypureclient.pure1.api.arrays_api import ArraysApi
from pypureclient.pure1.api.audits_api import AuditsApi
from pypureclient.pure1.api.authorization_api import AuthorizationApi
from pypureclient.pure1.api.file_system_snapshots_api import FileSystemSnapshotsApi
from pypureclient.pure1.api.file_systems_api import FileSystemsApi
from pypureclient.pure1.api.metrics_api import MetricsApi
from pypureclient.pure1.api.network_interfaces_api import NetworkInterfacesApi
from pypureclient.pure1.api.pods_api import PodsApi
from pypureclient.pure1.api.volume_snapshots_api import VolumeSnapshotsApi
from pypureclient.pure1.api.volumes_api import VolumesApi



# coding: utf-8

"""
    Pure1 Public REST API

    Pure1 Public REST API, developed by [Pure Storage, Inc.](http://www.purestorage.com/)  [Knowledge base reference documentation](https://support.purestorage.com/Pure1/Pure1_Manage/Pure1_Manage_-_REST_API/Pure1_Manage_-_REST_API__Reference)  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from pypureclient.pure1.models.fixed_reference import FixedReference  # noqa: F401,E501


class PodArrayStatus(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'str',
        'name': 'str',
        'resource_type': 'str',
        'frozen_at': 'int',
        'mediator_status': 'str',
        'status': 'str'
    }

    attribute_map = {
        'id': 'id',
        'name': 'name',
        'resource_type': 'resource_type',
        'frozen_at': 'frozen_at',
        'mediator_status': 'mediator_status',
        'status': 'status'
    }

    def __init__(self, id=None, name=None, resource_type=None, frozen_at=None, mediator_status=None, status=None):  # noqa: E501
        """PodArrayStatus - a model defined in Swagger"""  # noqa: E501

        self._id = None
        self._name = None
        self._resource_type = None
        self._frozen_at = None
        self._mediator_status = None
        self._status = None
        self.discriminator = None

        self.id = id
        self.name = name
        self.resource_type = resource_type
        self.frozen_at = frozen_at
        self.mediator_status = mediator_status
        self.status = status

    @property
    def id(self):
        """Gets the id of this PodArrayStatus.  # noqa: E501

        The opaque and unique id of this resource.  # noqa: E501

        :return: The id of this PodArrayStatus.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this PodArrayStatus.

        The opaque and unique id of this resource.  # noqa: E501

        :param id: The id of this PodArrayStatus.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def name(self):
        """Gets the name of this PodArrayStatus.  # noqa: E501

        The name of this resource  # noqa: E501

        :return: The name of this PodArrayStatus.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this PodArrayStatus.

        The name of this resource  # noqa: E501

        :param name: The name of this PodArrayStatus.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def resource_type(self):
        """Gets the resource_type of this PodArrayStatus.  # noqa: E501

        The type of this resource represented by the name of its REST endpoint. For example, \"arrays\", \"network-interfaces\", and \"metrics\".  # noqa: E501

        :return: The resource_type of this PodArrayStatus.  # noqa: E501
        :rtype: str
        """
        return self._resource_type

    @resource_type.setter
    def resource_type(self, resource_type):
        """Sets the resource_type of this PodArrayStatus.

        The type of this resource represented by the name of its REST endpoint. For example, \"arrays\", \"network-interfaces\", and \"metrics\".  # noqa: E501

        :param resource_type: The resource_type of this PodArrayStatus.  # noqa: E501
        :type: str
        """

        self._resource_type = resource_type

    @property
    def frozen_at(self):
        """Gets the frozen_at of this PodArrayStatus.  # noqa: E501

        The Unix timestamp of when the array was last in sync with the pod. (or null if the array is currently in sync)  # noqa: E501

        :return: The frozen_at of this PodArrayStatus.  # noqa: E501
        :rtype: int
        """
        return self._frozen_at

    @frozen_at.setter
    def frozen_at(self, frozen_at):
        """Sets the frozen_at of this PodArrayStatus.

        The Unix timestamp of when the array was last in sync with the pod. (or null if the array is currently in sync)  # noqa: E501

        :param frozen_at: The frozen_at of this PodArrayStatus.  # noqa: E501
        :type: int
        """

        self._frozen_at = frozen_at

    @property
    def mediator_status(self):
        """Gets the mediator_status of this PodArrayStatus.  # noqa: E501

        The status of the mediator as assessed by this array. Possible values are flummoxed, online, unknown, and unreachable. flummoxed - The array has the wrong UUID for the mediator. This means that the array can reach a mediator, but is talking to the wrong one. Typically, this would be due to a misconfiguration in the customer environment (e.g. DNS misconfiguration). UUIDs also have a TTL. If a pod goes offline on one array, and stays like that for weeks (such that the TTL expires), it may also show this status until the peer array is reachable again. online - The array is successfully communicating with the mediator. unreachable - The array cannot reach the mediator. This could be due to a network issue or the mediator is down.  # noqa: E501

        :return: The mediator_status of this PodArrayStatus.  # noqa: E501
        :rtype: str
        """
        return self._mediator_status

    @mediator_status.setter
    def mediator_status(self, mediator_status):
        """Sets the mediator_status of this PodArrayStatus.

        The status of the mediator as assessed by this array. Possible values are flummoxed, online, unknown, and unreachable. flummoxed - The array has the wrong UUID for the mediator. This means that the array can reach a mediator, but is talking to the wrong one. Typically, this would be due to a misconfiguration in the customer environment (e.g. DNS misconfiguration). UUIDs also have a TTL. If a pod goes offline on one array, and stays like that for weeks (such that the TTL expires), it may also show this status until the peer array is reachable again. online - The array is successfully communicating with the mediator. unreachable - The array cannot reach the mediator. This could be due to a network issue or the mediator is down.  # noqa: E501

        :param mediator_status: The mediator_status of this PodArrayStatus.  # noqa: E501
        :type: str
        """

        self._mediator_status = mediator_status

    @property
    def status(self):
        """Gets the status of this PodArrayStatus.  # noqa: E501

        Status of an array in the pod. Possible values are offline, online, resyncing, and unknown. offline - There is a problem. This array cannot confirm it has the latest data for this pod. This array can not handle IO to the pod nor could it take over during an HA event. online - Everything is fine. This array has the latest data for this pod. This array can handle IO to the pod and can take over during an HA event. resyncing - There was a problem. This array is actively catching up to get the latest data for this pod. This array can handle IO to this pod's volumes, however it could not take over during an HA event. unknown - The state of the pod on this array cannot be determined. This state is only seen on disconnected arrays. The disconnected array cannot determine if the pod on another array is online or offline.  # noqa: E501

        :return: The status of this PodArrayStatus.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this PodArrayStatus.

        Status of an array in the pod. Possible values are offline, online, resyncing, and unknown. offline - There is a problem. This array cannot confirm it has the latest data for this pod. This array can not handle IO to the pod nor could it take over during an HA event. online - Everything is fine. This array has the latest data for this pod. This array can handle IO to the pod and can take over during an HA event. resyncing - There was a problem. This array is actively catching up to get the latest data for this pod. This array can handle IO to this pod's volumes, however it could not take over during an HA event. unknown - The state of the pod on this array cannot be determined. This state is only seen on disconnected arrays. The disconnected array cannot determine if the pod on another array is online or offline.  # noqa: E501

        :param status: The status of this PodArrayStatus.  # noqa: E501
        :type: str
        """

        self._status = status

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(PodArrayStatus, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PodArrayStatus):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8
# flake8: noqa


from __future__ import absolute_import
import os

from pypureclient.pure1.client import Client
from pypureclient.pure1.exceptions import PureError
from pypureclient.pure1.properties import Property, Filter
from pypureclient.pure1.responses import ValidResponse, ErrorResponse, ApiError, Pure1Headers

from pypureclient.pure1.models.alert import Alert
from pypureclient.pure1.models.array import Array
from pypureclient.pure1.models.audit import Audit
from pypureclient.pure1.models.file_system import FileSystem
from pypureclient.pure1.models.file_system_snapshot import FileSystemSnapshot
from pypureclient.pure1.models.fixed_reference import FixedReference
from pypureclient.pure1.models.http import Http
from pypureclient.pure1.models.metric import Metric
from pypureclient.pure1.models.metric_availability import MetricAvailability
from pypureclient.pure1.models.metric_history import MetricHistory
from pypureclient.pure1.models.network_interface import NetworkInterface
from pypureclient.pure1.models.nfs import Nfs
from pypureclient.pure1.models.pod import Pod
from pypureclient.pure1.models.pod_array_status import PodArrayStatus
from pypureclient.pure1.models.smb import Smb
from pypureclient.pure1.models.tag import Tag
from pypureclient.pure1.models.volume import Volume
from pypureclient.pure1.models.volume_snapshot import VolumeSnapshot


def addProperties(model):
    for name, value in model.attribute_map.items():
        setattr(model, name, Property(value))

CLASSES_TO_ADD_PROPS = [Alert, Array, Audit, FileSystem, FileSystemSnapshot,
                        Http, Metric, MetricAvailability, MetricHistory,
                        NetworkInterface, Nfs, Pod, PodArrayStatus, Smb, Tag,
                        Volume, VolumeSnapshot]

if os.environ.get('DOCS_GENERATION') is None:
    for model in CLASSES_TO_ADD_PROPS:
        addProperties(model)



import json
import os
import time

from pypureclient.pure1.api_client import ApiClient
from pypureclient.pure1.exceptions import PureError
from pypureclient.pure1.keywords import Parameters, Headers, Responses
from pypureclient.pure1.responses import ValidResponse, ErrorResponse, Pure1Headers, ApiError, ItemIterator
from pypureclient.pure1.rest import ApiException
from pypureclient.pure1.token_manager import TokenManager
from . import api
from . import models


class Client(object):
    '''
    A client for making REST API calls to Pure1.
    '''
    def __init__(self, **kwargs):
        '''
        Initialize a Pure1 Client.

        Keyword args:
            app_id (str, optional): The registered App ID for Pure1 to use.
                Defaults to the set envioronment variable under PURE1_APP_ID.
            id_token (str, optional): The ID token to use. Overrides given
                App ID and private key. Defaults to environment variable set
                under PURE1_ID_TOKEN.
            private_key_file (str, optional): The path of the private key to
                use. Defaults to the set envioronment variable under
                PURE1_PRIVATE_KEY_FILE.
            private_key_password (str, optional): The password of the private
                key, if encrypted. Defaults to the set envioronment variable
                under PURE1_PRIVATE_KEY_FILE. Defaults to None.
            retires (int, optional): The number of times to retry an API call if
                it failed for a non-blocking reason. Defaults to 5.
            timeout (float or (float, float), optional): The timeout
                duration in seconds, either in total time or (connect and read)
                times. Defaults to 15.0 total.

        Raises:
            PureError: If it could not create an ID or access token
        '''
        # Class constants
        self.APP_ID_KEY = 'app_id'
        self.APP_ID_ENV = 'PURE1_APP_ID'
        self.ID_TOKEN_KEY = 'id_token'
        self.ID_TOKEN_ENV = 'PURE1_ID_TOKEN'
        self.PRIVATE_KEY_FILE_KEY = 'private_key_file'
        self.PRIVATE_KEY_FILE_ENV = 'PURE1_PRIVATE_KEY_FILE'
        self.PRIVATE_KEY_PASSWORD_KEY = 'private_key_password'
        self.PRIVATE_KEY_PASSWORD_ENV = 'PURE1_PRIVATE_KEY_PASSWORD'
        self.RETRIES_KEY = 'retries'
        self.RETRIES_DEFAULT = 5
        self.TOKEN_ENDPOINT = 'https://api.pure1.purestorage.com/oauth2/1.0/token'
        self.TIMEOUT_KEY = 'timeout'
        self.TIMEOUT_DEFAULT = 15.0
        self.USER_AGENT = 'Pure1/PythonSDK/1.0.1'
        # Read ID and key from kwargs or env variables (kwargs override)
        app_id = (kwargs.get(self.APP_ID_KEY)
                  if self.APP_ID_KEY in kwargs
                  else os.getenv(self.APP_ID_ENV))
        private_key_file = (kwargs.get(self.PRIVATE_KEY_FILE_KEY)
                            if self.PRIVATE_KEY_FILE_KEY in kwargs
                            else os.getenv(self.PRIVATE_KEY_FILE_ENV))
        private_key_password = (kwargs.get(self.PRIVATE_KEY_PASSWORD_KEY)
                                if self.PRIVATE_KEY_PASSWORD_KEY in kwargs
                                else os.getenv(self.PRIVATE_KEY_PASSWORD_ENV))
        id_token = (kwargs.get(self.ID_TOKEN_KEY)
                    if self.ID_TOKEN_KEY in kwargs
                    else os.getenv(self.ID_TOKEN_ENV))
        self._token_man = TokenManager(self.TOKEN_ENDPOINT,
                                       app_id=app_id,
                                       private_key_file=private_key_file,
                                       private_key_password=private_key_password,
                                       id_token=id_token)
        # Read timeout and retries from kwargs
        self._retries = (kwargs.get(self.RETRIES_KEY)
                         if self.RETRIES_KEY in kwargs
                         else self.RETRIES_DEFAULT)
        self._timeout = (kwargs.get(self.TIMEOUT_KEY)
                         if (self.TIMEOUT_KEY in kwargs and
                             isinstance(kwargs.get(self.TIMEOUT_KEY), (tuple, float)))
                         else self.TIMEOUT_DEFAULT)
        # Instantiate the client and authorize it
        self._api_client = ApiClient()
        self._set_agent_header()
        self._set_auth_header()
        # Instantiate the various APIs
        self._alerts_api = api.AlertsApi(self._api_client)
        self._arrays_api = api.ArraysApi(self._api_client)
        self._audits_api = api.AuditsApi(self._api_client)
        self._file_systems_api = api.FileSystemsApi(self._api_client)
        self._file_system_snapshots_api = api.FileSystemSnapshotsApi(self._api_client)
        self._metrics_api = api.MetricsApi(self._api_client)
        self._network_interfaces_api = api.NetworkInterfacesApi(self._api_client)
        self._pods_api = api.PodsApi(self._api_client)
        self._volumes_api = api.VolumesApi(self._api_client)
        self._volume_snapshots_api = api.VolumeSnapshotsApi(self._api_client)

    def get_access_token(self, refresh=False):
        '''
        Get the last used access token.

        Args:
            refresh (bool, optional):
                Whether to retrieve a new access token. Defaults to False.

        Returns:
            str

        Raises:
            PureError: If there was an error retrieving an access token.
        '''
        return self._token_man.get_access_token(refresh)

    def get_alerts(self, references=None, **kwargs):
        """
        Get alert objects.

        Args:
            references (list[FixedReference], optional):
                References to query for. Overrides ids and names keyword
                arguments. Can also be a single element.

        Keyword args:
            continuation_token (str, optional):
                An opaque token to iterate over a collection of resources.
            filter (Filter, optional): A filter to include only resources
                that match the specified criteria.
            ids (list[str], optional): Resource IDs to query for. Can also be a
                single element.
            limit (int, optional): Limit the number of resources in the
                response.
            names (list[str], optional): Resource names to query for. Can also
                be a single element.
            offset (int): The offset of the first resource to return from a
                collection.
            sort (list[Property], optional): Sort the response by the specified
                Properties. Can also be a single element.
            x_request_id (str, optional): A header to provide to track the
                API call. Generated by the server if not provided.

        Returns:
            ValidResponse: If the call was successful.
            ErrorResponse: If the call was not successful.

        Raises:
            TypeError: If invalid or missing parameters are used.
            ValueError: If a parameter is of an invalid type.
            PureError: If there was an error unpacking parameters or an unknown
                error occurred when trying to call the API.
        """
        ENDPOINT = self._alerts_api.api10_alerts_get_with_http_info
        if references is not None:
            kwargs = self._process_references_ids(references, kwargs)
        kwargs = self._process_kwargs(kwargs)
        response, is_error = self._call_api(ENDPOINT, kwargs, self._retries)
        return self._package_response(response, is_error, ENDPOINT, kwargs)

    def get_arrays(self, references=None, **kwargs):
        '''
        Get FlashArray and FlashBlade objects.

        Args:
            references (list[FixedReference], optional):
                References to query for. Overrides ids and names keyword
                arguments. Can also be a single element.

        Keyword args:
            continuation_token (str, optional):
                An opaque token to iterate over a collection of resources.
            filter (Filter, optional): A filter to include only resources
                that match the specified criteria.
            ids (list[str], optional): Resource IDs to query for. Can also be a
                single element.
            limit (int, optional): Limit the number of resources in the
                response.
            names (list[str], optional): Resource names to query for. Can also
                be a single element.
            offset (int): The offset of the first resource to return from a
                collection.
            sort (list[Property], optional): Sort the response by the specified
                Properties. Can also be a single element.
            x_request_id (str, optional): A header to provide to track the
                API call. Generated by the server if not provided.

        Returns:
            ValidResponse: If the call was successful.
            ErrorResponse: If the call was not successful.

        Raises:
            TypeError: If invalid or missing parameters are used.
            ValueError: If a parameter is of an invalid type.
            PureError: If there was an error unpacking parameters or an unknown
                error occurred when trying to call the API.
        '''
        ENDPOINT = self._arrays_api.api10_arrays_get_with_http_info
        if references is not None:
            kwargs = self._process_references_ids(references, kwargs)
        kwargs = self._process_kwargs(kwargs)
        response, is_error = self._call_api(ENDPOINT, kwargs, self._retries)
        return self._package_response(response, is_error, ENDPOINT, kwargs)

    def get_arrays_tags(self, resources=None, **kwargs):
        '''
        Get tags on arrays.

        Args:
            resources (list[FixedReference], optional): References to query
                for. Overrides resource_ids and resource_names keyword arguments.

        Keyword args:
            continuation_token (str, optional): An opaque token to iterate over
                a collection of resources.
            filter (Filter, optional): A filter to include only resources
                that match the specified criteria.
            keys (list[str], optional): A list of tag keys. Can also be a
                single element.
            limit (int, optional): Limit the number of resources in the
                response.
            namespaces (list[str], optional): Namespaces to query for. Can also
                be a single element.
            offset (int): The offset of the first resource to return from a
                collection.
            resource_ids (list[str], optional): Resource ids to get tags for.
                Can also be a single element.
            resource_names (list[str], optional): Resource names to get tags
                for. Can also be a single element.
            x_request_id (str, optional): A header to provide to track the
                API call. Generated by the server if not provided.

        Returns:
            ValidResponse: If the call was successful.
            ErrorResponse: If the call was not successful.

        Raises:
            TypeError: If invalid or missing parameters are used.
            ValueError: If a parameter is of an invalid type.
            PureError: If there was an error unpacking parameters or an unknown
                error occurred when trying to call the API.
        '''
        ENDPOINT = self._arrays_api.api10_arrays_tags_get_with_http_info
        if resources is not None:
            kwargs = self._process_references_resource_ids(resources, kwargs)
        kwargs = self._process_kwargs(kwargs)
        response, is_error = self._call_api(ENDPOINT, kwargs, self._retries)
        return self._package_response(response, is_error, ENDPOINT, kwargs)

    def delete_arrays_tags(self, resources=None, **kwargs):
        '''
        Delete tags from arrays.

        Args:
            resources (list[FixedReference], optional): References of resource
                to get tags for. Overrides resource_ids and resource_names.
                Can also be a single element.

        Keyword args:
            keys (list[str], optional): A list of tag keys. Can also be a
                single element.
            namespaces (list[str], optional): A list of namespaces. Can also
                be a single element.
            resource_ids (list[str], optional): Resource ids to get tags for.
                Can also be a single element.
            resource_names (list[str], optional): Resource names to get tags
                for. Can also be a single element.
            x_request_id (str, optional): A header to provide to track the
                API call. Generated by the server if not provided.

        Returns:
            ValidResponse: If the call was successful.
            ErrorResponse: If the call was not successful.

        Raises:
            TypeError: If invalid or missing parameters are used.
            ValueError: If a parameter is of an invalid type.
            PureError: If there was an error unpacking parameters or an unknown
                error occurred when trying to call the API.
        '''
        ENDPOINT = self._arrays_api.api10_arrays_tags_delete_with_http_info
        if resources is not None:
            kwargs = self._process_references_resource_ids(resources, kwargs)
        kwargs = self._process_kwargs(kwargs)
        response, is_error = self._call_api(ENDPOINT, kwargs, self._retries)
        return self._package_response(response, is_error, ENDPOINT, kwargs)

    def put_arrays_tags(self, resources=None, **kwargs):
        '''
        Put tags on arrays.

        Args:
            resources (list[FixedReference], optional): References of resources
                to put tags for. Overrides resource_ids and resource_names.
                Can also be a single element.

        Keyword args:
            namespaces (list[str], optional): A list of namespaces. Can also
                be a single element.
            resource_ids (list[str], optional): Resource ids to get tags for.
                Can also be a single element.
            resource_names (list[str], optional): Resource names to get tags
                for. Can also be a single element.
            tag (list[dict], required): A list of single key-value tags to put.
                Each dict must have one key-value pair. Can also be a single
                element.
            x_request_id (str, optional): A header to provide to track the
                API call. Generated by the server if not provided.

        Returns:
            ValidResponse: If the call was successful.
            ErrorResponse: If the call was not successful.

        Raises:
            TypeError: If invalid or missing parameters are used.
            ValueError: If a parameter is of an invalid type.
            PureError: If there was an error unpacking parameters or an unknown
                error occurred when trying to call the API.
        '''
        ENDPOINT = self._arrays_api.api10_arrays_tags_batch_put_with_http_info
        if Parameters.tag in kwargs:
            # Process array tags into the expected type
            raw_tags = kwargs.get(Parameters.tag)
            tag_list = []
            if not isinstance(raw_tags, list):
                raw_tags = [raw_tags]
            for tags in raw_tags:
            # There might be multiple key-value pairs in a single dict element
                for k, v in tags.items():
                    tag_list.append(models.Tag1(k, v))
            kwargs[Parameters.tag] = tag_list
        if resources is not None:
            kwargs = self._process_references_resource_ids(resources, kwargs)
        kwargs = self._process_kwargs(kwargs)
        response, is_error = self._call_api(ENDPOINT, kwargs, self._retries)
        return self._package_response(response, is_error, ENDPOINT, kwargs)

    def get_audits(self, references=None, **kwargs):
        '''
        Get audit objects.

        Args:
            references (list[FixedReference], optional):
                References to query for. Overrides ids and names keyword
                arguments. Can also be a single element.

        Keyword args:
            continuation_token (str, optional):
                An opaque token to iterate over a collection of resources.
            filter (Filter, optional): A filter to include only resources
                that match the specified criteria.
            ids (list[str], optional): Resource IDs to query for. Can also be a
                single element.
            limit (int, optional): Limit the number of resources in the
                response.
            names (list[str], optional): Resource names to query for. Can also
                be a single element.
            offset (int): The offset of the first resource to return from a
                collection.
            sort (list[Property], optional): Sort the response by the specified
                Properties. Can also be a single element.
            x_request_id (str, optional): A header to provide to track the
                API call. Generated by the server if not provided.

        Returns:
            ValidResponse: If the call was successful.
            ErrorResponse: If the call was not successful.

        Raises:
            TypeError: If invalid or missing parameters are used.
            ValueError: If a parameter is of an invalid type.
            PureError: If there was an error unpacking parameters or an unknown
                error occurred when trying to call the API.
        '''
        ENDPOINT = self._audits_api.api10_audits_get_with_http_info
        if references is not None:
            kwargs = self._process_references_ids(references, kwargs)
        kwargs = self._process_kwargs(kwargs)
        response, is_error = self._call_api(ENDPOINT, kwargs, self._retries)
        return self._package_response(response, is_error, ENDPOINT, kwargs)

    def get_file_systems(self, references=None, **kwargs):
        '''
        Get FlashBlade file system objects.

        Args:
            references (list[FixedReference], optional): References to query
                for. Overrides ids and names keyword arguments.

        Keyword args:
            continuation_token (str, optional): An opaque token to iterate over
                a collection of resources.
            filter (Filter, optional): A filter to include only resources
                that match the specified criteria.
            ids (list[str], optional): Resource IDs to query for. Can also be a
                single element.
            limit (int, optional): Limit the number of resources in the
                response.
            names (list[str], optional): Resource names to query for. Can also
                be a single element.
            offset (int): The offset of the first resource to return from a
                collection.
            sort (list[Property], optional): Sort the response by the specified
                Properties. Can also be a single element.
            x_request_id (str, optional): A header to provide to track the
                API call. Generated by the server if not provided.

        Returns:
            ValidResponse: If the call was successful.
            ErrorResponse: If the call was not successful.

        Raises:
            TypeError: If invalid or missing parameters are used.
            ValueError: If a parameter is of an invalid type.
            PureError: If there was an error unpacking parameters or an unknown
                error occurred when trying to call the API.
        '''
        ENDPOINT = self._file_systems_api.api10_file_systems_get_with_http_info
        if references is not None:
            kwargs = self._process_references_ids(references, kwargs)
        kwargs = self._process_kwargs(kwargs)
        response, is_error = self._call_api(ENDPOINT, kwargs, self._retries)
        return self._package_response(response, is_error, ENDPOINT, kwargs)

    def get_file_system_snapshots(self, references=None, **kwargs):
        '''
        Get snapshots of file systems.

        Args:
            references (list[FixedReference], optional): References to query
                for. Overrides ids and names keyword arguments.

        Keyword args:
            continuation_token (str, optional): An opaque token to iterate over
                a collection of resources.
            filter (Filter, optional): A filter to include only resources
                that match the specified criteria.
            ids (list[str], optional): Resource IDs to query for. Can also be a
                single element.
            limit (int, optional): Limit the number of resources in the
                response.
            names (list[str], optional): Resource names to query for. Can also
                be a single element.
            offset (int): The offset of the first resource to return from a
                collection.
            sort (list[Property], optional): Sort the response by the specified
                Properties. Can also be a single element.
            source_ids (list[str], optional): IDs for source of the object
                to query for. Can also be a single element.
            source_names (list[str], optional): Names for source of the object
                to query for. Can also be a single element.
            x_request_id (str, optional): A header to provide to track the
                API call. Generated by the server if not provided.

        Returns:
            ValidResponse: If the call was successful.
            ErrorResponse: If the call was not successful.

        Raises:
            TypeError: If invalid or missing parameters are used.
            ValueError: If a parameter is of an invalid type.
            PureError: If there was an error unpacking parameters or an unknown
                error occurred when trying to call the API.
        '''
        ENDPOINT = self._file_system_snapshots_api.api10_file_system_snapshots_get_with_http_info
        if references is not None:
            kwargs = self._process_references_ids(references, kwargs)
        kwargs = self._process_kwargs(kwargs)
        response, is_error = self._call_api(ENDPOINT, kwargs, self._retries)
        return self._package_response(response, is_error, ENDPOINT, kwargs)

    def get_metrics(self, references=None, **kwargs):
        '''
        Get metrics which can be queried for.

        Args:
            references (list[FixedReference], optional): References to query
                for. Overrides ids and names keyword arguments.

        Keyword args:
            continuation_token (str, optional): An opaque token to iterate over
                a collection of resources.
            filter (Filter, optional): A filter to include only resources
                that match the specified criteria.
            ids (list[str], optional): Resource IDs to query for. Can also be a
                single element.
            limit (int, optional): Limit the number of resources in the
                response.
            names (list[str], optional): Resource names to query for. Can also
                be a single element.
            offset (int): The offset of the first resource to return from a
                collection.
            resource_types (list[str], optional): The resource types of the
                metrics to list. Currently accepted values are "arrays",
                "volumes", and "pods". Can also be a single element.
            sort (list[Property], optional): Sort the response by the specified
                Properties. Can also be a single element.
            x_request_id (str, optional): A header to provide to track the
                API call. Generated by the server if not provided.

        Returns:
            ValidResponse: If the call was successful.
            ErrorResponse: If the call was not successful.

        Raises:
            TypeError: If invalid or missing parameters are used.
            ValueError: If a parameter is of an invalid type.
            PureError: If there was an error unpacking parameters or an unknown
                error occurred when trying to call the API.
        '''
        ENDPOINT = self._metrics_api.api10_metrics_get_with_http_info
        if references is not None:
            kwargs = self._process_references_ids(references, kwargs)
        kwargs = self._process_kwargs(kwargs)
        response, is_error = self._call_api(ENDPOINT, kwargs, self._retries)
        return self._package_response(response, is_error, ENDPOINT, kwargs)

    def get_metrics_history(self, **kwargs):
        '''
        Get historical metric data for resources.

        Keyword args:
            aggregation (Property): Aggregation needed on the metric data.
            end_time (int): When the time window ends, in milliseconds since
                epoch.
            ids (list[str], optional): Resource IDs of metrics to query for.
                Can also be a single element.
            references (list[FixedReference], optional): References to metrics
                to get data for. Overrides ids and names. Can also be a single
                item.
            names (list[str], optional): Resource names of metrics to query for.
                Can also be a single element.
            resolution (int): Duration of time between data point, in
                milliseconds.
            resources (list[FixedReference], optional): References of resources
                to get metrics for. Overrides resource_ids and resource_names.
                Can also be a single element.
            resource_ids (list[str], optional): Resource ids to get metric
                data for. Can also be a single element.
            resource_names (list[str], optional): Resource names to get metric
                data for. Can also be a single element.
            sort (list[Property], optional): Sort the response by the specified
                Properties. Can also be a single element.
            start_time (int): When the time window start, in milliseconds since
                epoch.
            x_request_id (str, optional): A header to provide to track the
                API call. Generated by the server if not provided.

        Returns:
            ValidResponse: If the call was successful.
            ErrorResponse: If the call was not successful.

        Raises:
            TypeError: If invalid or missing parameters are used.
            ValueError: If a parameter is of an invalid type.
            PureError: If there was an error unpacking parameters or an unknown
                error occurred when trying to call the API.
        '''
        ENDPOINT = self._metrics_api.api10_metrics_history_get_with_http_info
        references = kwargs.get(Parameters.references, None)
        if references is not None:
            kwargs = self._process_references_ids(references, kwargs)
        resources = kwargs.get(Parameters.resources, None)
        if resources is not None:
            kwargs = self._process_references_resource_ids(resources, kwargs)
        kwargs = self._process_kwargs(kwargs)
        response, is_error = self._call_api(ENDPOINT, kwargs, self._retries)
        return self._package_response(response, is_error, ENDPOINT, kwargs)

    def get_network_interfaces(self, references=None, **kwargs):
        '''
        Get physical and virtual network interface objects.

        Args:
            references (list[FixedReference], optional): References to query
                for. Overrides ids and names keyword arguments.

        Keyword args:
            continuation_token (str, optional): An opaque token to iterate over
                a collection of resources.
            filter (Filter, optional): A filter to include only resources
                that match the specified criteria.
            ids (list[str], optional): Resource IDs to query for. Can also be a
                single element.
            limit (int, optional): Limit the number of resources in the
                response.
            names (list[str], optional): Resource names to query for. Can also
                be a single element.
            offset (int): The offset of the first resource to return from a
                collection.
            sort (list[Property], optional): Sort the response by the specified
                Properties. Can also be a single element.
            x_request_id (str, optional): A header to provide to track the
                API call. Generated by the server if not provided.

        Returns:
            ValidResponse: If the call was successful.
            ErrorResponse: If the call was not successful.

        Raises:
            TypeError: If invalid or missing parameters are used.
            ValueError: If a parameter is of an invalid type.
            PureError: If there was an error unpacking parameters or an unknown
                error occurred when trying to call the API.
        '''
        ENDPOINT = self._network_interfaces_api.api10_network_interfaces_get_with_http_info
        if references is not None:
            kwargs = self._process_references_ids(references, kwargs)
        kwargs = self._process_kwargs(kwargs)
        response, is_error = self._call_api(ENDPOINT, kwargs, self._retries)
        return self._package_response(response, is_error, ENDPOINT, kwargs)

    def get_pods(self, references=None, **kwargs):
        '''
        Get pod objects.

        Args:
            references (list[FixedReference], optional): References to query
                for. Overrides ids and names keyword arguments.

        Keyword args:
            continuation_token (str, optional): An opaque token to iterate over
                a collection of resources.
            filter (Filter, optional): A filter to include only resources
                that match the specified criteria.
            ids (list[str], optional): Resource IDs to query for. Can also be a
                single element.
            limit (int, optional): Limit the number of resources in the
                response.
            names (list[str], optional): Resource names to query for. Can also
                be a single element.
            offset (int): The offset of the first resource to return from a
                collection.
            sort (list[Property], optional): Sort the response by the specified
                Properties. Can also be a single element.
            x_request_id (str, optional): A header to provide to track the
                API call. Generated by the server if not provided.

        Returns:
            ValidResponse: If the call was successful.
            ErrorResponse: If the call was not successful.

        Raises:
            TypeError: If invalid or missing parameters are used.
            ValueError: If a parameter is of an invalid type.
            PureError: If there was an error unpacking parameters or an unknown
                error occurred when trying to call the API.
        '''
        ENDPOINT = self._pods_api.api10_pods_get_with_http_info
        if references is not None:
            kwargs = self._process_references_ids(references, kwargs)
        kwargs = self._process_kwargs(kwargs)
        response, is_error = self._call_api(ENDPOINT, kwargs, self._retries)
        return self._package_response(response, is_error, ENDPOINT, kwargs)

    def get_volumes(self, references=None, **kwargs):
        '''
        Get FlashArray volume objects.

        Args:
            references (list[FixedReference], optional): References to query
                for. Overrides ids and names keyword arguments.

        Keyword args:
            continuation_token (str, optional): An opaque token to iterate over
                a collection of resources.
            filter (Filter, optional): A filter to include only resources
                that match the specified criteria.
            ids (list[str], optional): Resource IDs to query for. Can also be a
                single element.
            limit (int, optional): Limit the number of resources in the
                response.
            names (list[str], optional): Resource names to query for. Can also
                be a single element.
            offset (int): The offset of the first resource to return from a
                collection.
            sort (list[Property], optional): Sort the response by the specified
                Properties. Can also be a single element.
            x_request_id (str, optional): A header to provide to track the
                API call. Generated by the server if not provided.

        Returns:
            ValidResponse: If the call was successful.
            ErrorResponse: If the call was not successful.

        Raises:
            TypeError: If invalid or missing parameters are used.
            ValueError: If a parameter is of an invalid type.
            PureError: If there was an error unpacking parameters or an unknown
                error occurred when trying to call the API.
        '''
        ENDPOINT = self._volumes_api.api10_volumes_get_with_http_info
        if references is not None:
            kwargs = self._process_references_ids(references, kwargs)
        kwargs = self._process_kwargs(kwargs)
        response, is_error = self._call_api(ENDPOINT, kwargs, self._retries)
        return self._package_response(response, is_error, ENDPOINT, kwargs)

    def get_volume_snapshots(self, references=None, **kwargs):
        '''
        Get snapshots of volumes.

        Args:
            references (list[FixedReference], optional): References to query
                for. Overrides ids and names keyword arguments.

        Keyword args:
            continuation_token (str, optional): An opaque token to iterate over
                a collection of resources.
            filter (Filter, optional): A filter to include only resources
                that match the specified criteria.
            ids (list[str], optional): Resource IDs to query for. Can also be a
                single element.
            limit (int, optional): Limit the number of resources in the
                response.
            names (list[str], optional): Resource names to query for. Can also
                be a single element.
            offset (int): The offset of the first resource to return from a
                collection.
            sort (list[Property], optional): Sort the response by the specified
                Properties. Can also be a single element.
            source_ids (list[str], optional): IDs for source of the object
                to query for. Can also be a single element.
            source_names (list[str], optional): Names for source of the object
                to query for. Can also be a single element.
            x_request_id (str, optional): A header to provide to track the
                API call. Generated by the server if not provided.

        Returns:
            ValidResponse: If the call was successful.
            ErrorResponse: If the call was not successful.

        Raises:
            TypeError: If invalid or missing parameters are used.
            ValueError: If a parameter is of an invalid type.
            PureError: If there was an error unpacking parameters or an unknown
                error occurred when trying to call the API.
        '''
        ENDPOINT = self._volume_snapshots_api.api10_volume_snapshots_get_with_http_info
        if references is not None:
            kwargs = self._process_references_ids(references, kwargs)
        kwargs = self._process_kwargs(kwargs)
        response, is_error = self._call_api(ENDPOINT, kwargs, self._retries)
        return self._package_response(response, is_error, ENDPOINT, kwargs)

    def _set_agent_header(self):
        '''
        Set the user-agent header of the internal client.
        '''
        self._api_client.set_default_header('User-Agent', self.USER_AGENT)

    def _set_auth_header(self, refresh=False):
        '''
        Set the authorization header of the internal client with the access
        token.

        Args:
            refresh (bool, optional): Whether to retrieve a new access token.
                Defaults to False.

        Raises:
            PureError: If there was an error retrieving the access token.
        '''
        self._api_client.set_default_header('Authorization',
                                            self._token_man.get_header(refresh=refresh))

    def _process_kwargs(self, kwargs):
        '''
        Process the client-defined kwargs into the format expected by swagger.

        Args:
            kwargs (dict): The kwargs to process.

        Returns:
            dict
        '''
        # NOTE: paramters that are lists are compressed into one single string
        #       then passed in as a list with a single element;
        #       this is so swagger does not improperly split the list and add
        #       a query parameter for each element in the list, but only once
        # Convert the filter into a string
        if Parameters.filter in kwargs:
            kwargs[Parameters.filter] = str(kwargs.get(Parameters.filter))
        # Convert list string parameters to lists with single quotes
        for param in Parameters.get_list_str_parameters():
            if param in kwargs:
                if isinstance(kwargs.get(param), list):
                    kwargs[param] = [','.join(['\'{}\''.format(element)
                                               for element in kwargs.get(param)])]
                else:
                    kwargs[param] = ['\'{}\''.format(kwargs.get(param))]
        # Convert list parameters to list (without quotes)
        for param in Parameters.get_list_parameters():
            if param in kwargs:
                if isinstance(kwargs.get(param), list):
                    kwargs[param] = [','.join([str(element)
                                               for element in kwargs.get(param)])]
                else:
                    kwargs[param] = [str(kwargs.get(param))]
        # Encapsulate simple string parameters with single quotes
        for param in Parameters.get_str_parameters():
            if param in kwargs:
                kwargs[param] = '\'{}\''.format(kwargs.get(param))
        # Add the timeout
        kwargs['_request_timeout'] = self._timeout
        return kwargs

    def _process_references_ids(self, references, kwargs):
        '''
        Process reference objects into a list of IDs. Removes other ID and name
        arguments.

        Args:
            references (list[FixedReference]): The references from which to
                extract IDs.
            kwargs (dict): The kwargs to process.

        Returns:
            dict

        Raises:
            PureError: If a reference does not have an ID attribute.
        '''
        self._verify_references(references)
        kwargs[Parameters.ids] = ([ref.id for ref in references]
                                   if isinstance(references, list)
                                   else [references.id])
        kwargs.pop(Parameters.references, None)
        kwargs.pop(Parameters.names, None)
        return kwargs

    def _process_references_resource_ids(self, references, kwargs):
        '''
        Process reference objects into a list of IDs. Removes other resource ID
        and resource name arguments.

        Args:
            references (list[FixedReference]): The references from which to
                extract IDs.
            kwargs (dict): The kwargs to process.

        Returns:
            dict

        Raises:
            PureError: If a reference does not have an ID attribute.
        '''
        self._verify_references(references)
        kwargs[Parameters.resource_ids] = ([ref.id for ref in references]
                                           if isinstance(references, list)
                                           else [references.id])
        kwargs.pop(Parameters.resources, None)
        kwargs.pop(Parameters.resource_names, None)
        return kwargs

    def _verify_references(self, references):
        '''
        Verify all references have an ID attribute.

        Args:
            references (list[FixedReference]): The references to verify. Can
                also be a single element.

        Raises:
            PureError: If a reference does not have an ID attribute.
        '''
        if isinstance(references, list):
            if not all(ref.id is not None for ref in references):
                PureError('References do not all contain IDs')
        else:
            if references.id is None:
                PureError('Reference does not contain an ID')

    def _call_api(self, api_function, kwargs, retries):
        '''
        Call the API function and process the response. May call the API
        repeatedly if the request failed for a resaon that may not persist in
        the next call.

        Args:
            api_function (function): The function of the Swagger client to
                call internally.
            kwargs (dict): The processed kwargs to pass to the function.
            retries (int): The number of retries left.

        Returns:
            tuple (body, status, headers)
            bool: Whether an error was encountered.

        Raises:
            PureError: If an unexpected error occurred.
        '''
        try:
            response = api_function(**kwargs)
            # Call was successful (200)
            return response, False
        except ApiException as error:
            # If no chance for retries, return the error
            if retries == 0:
                return error, True
            # If bad request or not found, return the error (it will never work)
            elif error.status in [400, 404]:
                return error, True
            # If authentication error, reset access token and retry
            elif error.status == 403:
                self._set_auth_header(refresh=True)
                return self._call_api(api_function, kwargs, retries - 1)
            # If rate limit error, wait the proper time and try again
            elif error.status == 429:
                # If the the minute limit hit, wait that long
                if (int(error.headers.get(Headers.x_ratelimit_remaining_min))
                    == int(error.headers.get(Headers.x_ratelimit_min))):
                    time.sleep(60)
                # Otherwise it was the second limit and only wait a second
                time.sleep(1)
                return self._call_api(api_function, kwargs, retries - 1)
            # If some internal server error we know nothing about, return
            elif error.status == 500:
                return error, True
            # If internal server errors that has to do with timeouts, try again
            elif error.status > 500:
                return self._call_api(api_function, kwargs, retries - 1)
            # If error with the swagger client, raise the error
            else:
                raise PureError(error)

    def _package_response(self, response, is_error, endpoint, kwargs):
        '''
        Package a response into a ValidResponse or ErrorResponse.

        Args:
            response (tuple, ApiException): Body, status, header tuple as
                returned from a Swagger client, or an ApiException.
            is_error (bool): Whether the response is an error.
            endpoint (function): The function of the Swagger client that was
                called.
            kwargs (dict): The processed kwargs that were passed to the
                endpoint function.

        Returns:
            ValidResponse or ErrorResponse
        '''
        return (self._create_valid_response(response, endpoint, kwargs)
                if is_error is False
                else self._create_error_response(response))

    def _create_valid_response(self, response, endpoint, kwargs):
        '''
        Create a ValidResponse from a Swagger response.

        Args:
            response (tuple): Body, status, header tuple as returned from a
                Swagger client.
            endpoint (function): The function of the Swagger client that was
                called.
            kwargs (dict): The processed kwargs that were passed to the
                endpoint function.

        Returns:
            ValidResponse
        '''
        body, status, headers = response
        if body is None:
            continuation_token = None
            total_item_count = None
            items = None
        else:
            if not hasattr(body, Parameters.continuation_token):
                continuation_token = None
                total_item_count = len(body.items)
            else:
                continuation_token = body.continuation_token
                total_item_count = body.total_item_count
            items = iter(ItemIterator(self, endpoint, kwargs,
                                      continuation_token, total_item_count,
                                      body.items,
                                      headers.get(Headers.x_request_id)))
        pure1_headers = Pure1Headers(headers.get(Headers.x_request_id, None),
                                     headers.get(Headers.x_ratelimit_sec, None),
                                     headers.get(Headers.x_ratelimit_min, None),
                                     headers.get(Headers.x_ratelimit_remaining_sec, None),
                                     headers.get(Headers.x_ratelimit_remaining_min, None))
        return ValidResponse(status, continuation_token, total_item_count,
                             items, headers=pure1_headers)

    def _create_error_response(self, error):
        '''
        Create an ErrorResponse from a Swagger error.

        Args:
            error (ApiException): Error returned raised by Swagger.

        Returns:
            ErrorResponse
        '''
        status = error.status
        body = json.loads(error.body)
        if status in [403, 429]:
            # Parse differently if the error message came from kong
            errors = [ApiError(None, body.get(Responses.message, None))]
        else:
            errors = [ApiError(err.get(Responses.context, None),
                               err.get(Responses.message, None))
                      for err in body.get(Responses.errors, None)]
        headers = error.headers
        pure1_headers = Pure1Headers(headers.get(Headers.x_request_id, None),
                                     headers.get(Headers.x_ratelimit_sec, None),
                                     headers.get(Headers.x_ratelimit_min, None),
                                     headers.get(Headers.x_ratelimit_remaining_sec, None),
                                     headers.get(Headers.x_ratelimit_remaining_min, None))
        return ErrorResponse(status, errors, headers=pure1_headers)



# coding: utf-8

"""
    Pure1 Public REST API

    Pure1 Public REST API, developed by [Pure Storage, Inc.](http://www.purestorage.com/)  [Knowledge base reference documentation](https://support.purestorage.com/Pure1/Pure1_Manage/Pure1_Manage_-_REST_API/Pure1_Manage_-_REST_API__Reference)  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from pypureclient.pure1.models.arrays_built_in import ArraysBuiltIn  # noqa: F401,E501
from pypureclient.pure1.models.fixed_reference import FixedReference  # noqa: F401,E501


class NetworkInterface(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'as_of': 'int',
        'id': 'str',
        'name': 'str',
        'arrays': 'list[FixedReference]',
        'address': 'str',
        'enabled': 'bool',
        'gateway': 'str',
        'hwaddr': 'str',
        'mtu': 'int',
        'netmask': 'str',
        'services': 'list[str]',
        'speed': 'int',
        'subinterfaces': 'list[str]'
    }

    attribute_map = {
        'as_of': '_as_of',
        'id': 'id',
        'name': 'name',
        'arrays': 'arrays',
        'address': 'address',
        'enabled': 'enabled',
        'gateway': 'gateway',
        'hwaddr': 'hwaddr',
        'mtu': 'mtu',
        'netmask': 'netmask',
        'services': 'services',
        'speed': 'speed',
        'subinterfaces': 'subinterfaces'
    }

    def __init__(self, as_of=None, id=None, name=None, arrays=None, address=None, enabled=None, gateway=None, hwaddr=None, mtu=None, netmask=None, services=None, speed=None, subinterfaces=None):  # noqa: E501
        """NetworkInterface - a model defined in Swagger"""  # noqa: E501

        self._as_of = None
        self._id = None
        self._name = None
        self._arrays = None
        self._address = None
        self._enabled = None
        self._gateway = None
        self._hwaddr = None
        self._mtu = None
        self._netmask = None
        self._services = None
        self._speed = None
        self._subinterfaces = None
        self.discriminator = None

        self.as_of = as_of
        self.id = id
        self.name = name
        self.arrays = arrays
        self.address = address
        self.enabled = enabled
        self.gateway = gateway
        self.hwaddr = hwaddr
        self.mtu = mtu
        self.netmask = netmask
        self.services = services
        self.speed = speed
        self.subinterfaces = subinterfaces

    @property
    def as_of(self):
        """Gets the as_of of this NetworkInterface.  # noqa: E501

        The freshness of the data (timestamp in millis since epoch)  # noqa: E501

        :return: The as_of of this NetworkInterface.  # noqa: E501
        :rtype: int
        """
        return self._as_of

    @as_of.setter
    def as_of(self, as_of):
        """Sets the as_of of this NetworkInterface.

        The freshness of the data (timestamp in millis since epoch)  # noqa: E501

        :param as_of: The as_of of this NetworkInterface.  # noqa: E501
        :type: int
        """
        if as_of is None:
            raise ValueError("Invalid value for `as_of`, must not be `None`")  # noqa: E501

        self._as_of = as_of

    @property
    def id(self):
        """Gets the id of this NetworkInterface.  # noqa: E501

        A non-modifiable, globally unique ID chosen by the system.  # noqa: E501

        :return: The id of this NetworkInterface.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this NetworkInterface.

        A non-modifiable, globally unique ID chosen by the system.  # noqa: E501

        :param id: The id of this NetworkInterface.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def name(self):
        """Gets the name of this NetworkInterface.  # noqa: E501

        A non-modifiable, locally unique name chosen by the system.  # noqa: E501

        :return: The name of this NetworkInterface.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this NetworkInterface.

        A non-modifiable, locally unique name chosen by the system.  # noqa: E501

        :param name: The name of this NetworkInterface.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def arrays(self):
        """Gets the arrays of this NetworkInterface.  # noqa: E501

        The list of arrays where this resource exists. Many resources are on a single array, but some resources - for example pods - can be stretched across multiple arrays.  # noqa: E501

        :return: The arrays of this NetworkInterface.  # noqa: E501
        :rtype: list[FixedReference]
        """
        return self._arrays

    @arrays.setter
    def arrays(self, arrays):
        """Sets the arrays of this NetworkInterface.

        The list of arrays where this resource exists. Many resources are on a single array, but some resources - for example pods - can be stretched across multiple arrays.  # noqa: E501

        :param arrays: The arrays of this NetworkInterface.  # noqa: E501
        :type: list[FixedReference]
        """

        self._arrays = arrays

    @property
    def address(self):
        """Gets the address of this NetworkInterface.  # noqa: E501

        IP address of this network interface  # noqa: E501

        :return: The address of this NetworkInterface.  # noqa: E501
        :rtype: str
        """
        return self._address

    @address.setter
    def address(self, address):
        """Sets the address of this NetworkInterface.

        IP address of this network interface  # noqa: E501

        :param address: The address of this NetworkInterface.  # noqa: E501
        :type: str
        """

        self._address = address

    @property
    def enabled(self):
        """Gets the enabled of this NetworkInterface.  # noqa: E501


        :return: The enabled of this NetworkInterface.  # noqa: E501
        :rtype: bool
        """
        return self._enabled

    @enabled.setter
    def enabled(self, enabled):
        """Sets the enabled of this NetworkInterface.


        :param enabled: The enabled of this NetworkInterface.  # noqa: E501
        :type: bool
        """

        self._enabled = enabled

    @property
    def gateway(self):
        """Gets the gateway of this NetworkInterface.  # noqa: E501


        :return: The gateway of this NetworkInterface.  # noqa: E501
        :rtype: str
        """
        return self._gateway

    @gateway.setter
    def gateway(self, gateway):
        """Sets the gateway of this NetworkInterface.


        :param gateway: The gateway of this NetworkInterface.  # noqa: E501
        :type: str
        """

        self._gateway = gateway

    @property
    def hwaddr(self):
        """Gets the hwaddr of this NetworkInterface.  # noqa: E501

        Hardware address  # noqa: E501

        :return: The hwaddr of this NetworkInterface.  # noqa: E501
        :rtype: str
        """
        return self._hwaddr

    @hwaddr.setter
    def hwaddr(self, hwaddr):
        """Sets the hwaddr of this NetworkInterface.

        Hardware address  # noqa: E501

        :param hwaddr: The hwaddr of this NetworkInterface.  # noqa: E501
        :type: str
        """

        self._hwaddr = hwaddr

    @property
    def mtu(self):
        """Gets the mtu of this NetworkInterface.  # noqa: E501

        Maximum transmission unit  # noqa: E501

        :return: The mtu of this NetworkInterface.  # noqa: E501
        :rtype: int
        """
        return self._mtu

    @mtu.setter
    def mtu(self, mtu):
        """Sets the mtu of this NetworkInterface.

        Maximum transmission unit  # noqa: E501

        :param mtu: The mtu of this NetworkInterface.  # noqa: E501
        :type: int
        """

        self._mtu = mtu

    @property
    def netmask(self):
        """Gets the netmask of this NetworkInterface.  # noqa: E501


        :return: The netmask of this NetworkInterface.  # noqa: E501
        :rtype: str
        """
        return self._netmask

    @netmask.setter
    def netmask(self, netmask):
        """Sets the netmask of this NetworkInterface.


        :param netmask: The netmask of this NetworkInterface.  # noqa: E501
        :type: str
        """

        self._netmask = netmask

    @property
    def services(self):
        """Gets the services of this NetworkInterface.  # noqa: E501

        services and protocols that are enabled on the interface  # noqa: E501

        :return: The services of this NetworkInterface.  # noqa: E501
        :rtype: list[str]
        """
        return self._services

    @services.setter
    def services(self, services):
        """Sets the services of this NetworkInterface.

        services and protocols that are enabled on the interface  # noqa: E501

        :param services: The services of this NetworkInterface.  # noqa: E501
        :type: list[str]
        """

        self._services = services

    @property
    def speed(self):
        """Gets the speed of this NetworkInterface.  # noqa: E501

        Speed in bytes per second  # noqa: E501

        :return: The speed of this NetworkInterface.  # noqa: E501
        :rtype: int
        """
        return self._speed

    @speed.setter
    def speed(self, speed):
        """Sets the speed of this NetworkInterface.

        Speed in bytes per second  # noqa: E501

        :param speed: The speed of this NetworkInterface.  # noqa: E501
        :type: int
        """

        self._speed = speed

    @property
    def subinterfaces(self):
        """Gets the subinterfaces of this NetworkInterface.  # noqa: E501


        :return: The subinterfaces of this NetworkInterface.  # noqa: E501
        :rtype: list[str]
        """
        return self._subinterfaces

    @subinterfaces.setter
    def subinterfaces(self, subinterfaces):
        """Sets the subinterfaces of this NetworkInterface.


        :param subinterfaces: The subinterfaces of this NetworkInterface.  # noqa: E501
        :type: list[str]
        """

        self._subinterfaces = subinterfaces

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(NetworkInterface, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, NetworkInterface):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Pure1 Public REST API

    Pure1 Public REST API, developed by [Pure Storage, Inc.](http://www.purestorage.com/)  [Knowledge base reference documentation](https://support.purestorage.com/Pure1/Pure1_Manage/Pure1_Manage_-_REST_API/Pure1_Manage_-_REST_API__Reference)  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from pypureclient.pure1.models.arrays_built_in import ArraysBuiltIn  # noqa: F401,E501
from pypureclient.pure1.models.fixed_reference import FixedReference  # noqa: F401,E501


class VolumeSnapshot(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'as_of': 'int',
        'id': 'str',
        'name': 'str',
        'arrays': 'list[FixedReference]',
        'created': 'int',
        'destroyed': 'bool',
        'on': 'FixedReference',
        'pod': 'FixedReference',
        'provisioned': 'int',
        'serial': 'str',
        'snapshot_group': 'FixedReference',
        'source': 'FixedReference',
        'suffix': 'str'
    }

    attribute_map = {
        'as_of': '_as_of',
        'id': 'id',
        'name': 'name',
        'arrays': 'arrays',
        'created': 'created',
        'destroyed': 'destroyed',
        'on': 'on',
        'pod': 'pod',
        'provisioned': 'provisioned',
        'serial': 'serial',
        'snapshot_group': 'snapshot_group',
        'source': 'source',
        'suffix': 'suffix'
    }

    def __init__(self, as_of=None, id=None, name=None, arrays=None, created=None, destroyed=None, on=None, pod=None, provisioned=None, serial=None, snapshot_group=None, source=None, suffix=None):  # noqa: E501
        """VolumeSnapshot - a model defined in Swagger"""  # noqa: E501

        self._as_of = None
        self._id = None
        self._name = None
        self._arrays = None
        self._created = None
        self._destroyed = None
        self._on = None
        self._pod = None
        self._provisioned = None
        self._serial = None
        self._snapshot_group = None
        self._source = None
        self._suffix = None
        self.discriminator = None

        self.as_of = as_of
        self.id = id
        self.name = name
        self.arrays = arrays
        self.created = created
        self.destroyed = destroyed
        self.on = on
        self.pod = pod
        self.provisioned = provisioned
        self.serial = serial
        self.snapshot_group = snapshot_group
        self.source = source
        self.suffix = suffix

    @property
    def as_of(self):
        """Gets the as_of of this VolumeSnapshot.  # noqa: E501

        The freshness of the data (timestamp in millis since epoch)  # noqa: E501

        :return: The as_of of this VolumeSnapshot.  # noqa: E501
        :rtype: int
        """
        return self._as_of

    @as_of.setter
    def as_of(self, as_of):
        """Sets the as_of of this VolumeSnapshot.

        The freshness of the data (timestamp in millis since epoch)  # noqa: E501

        :param as_of: The as_of of this VolumeSnapshot.  # noqa: E501
        :type: int
        """
        if as_of is None:
            raise ValueError("Invalid value for `as_of`, must not be `None`")  # noqa: E501

        self._as_of = as_of

    @property
    def id(self):
        """Gets the id of this VolumeSnapshot.  # noqa: E501

        A non-modifiable, globally unique ID chosen by the system.  # noqa: E501

        :return: The id of this VolumeSnapshot.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this VolumeSnapshot.

        A non-modifiable, globally unique ID chosen by the system.  # noqa: E501

        :param id: The id of this VolumeSnapshot.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def name(self):
        """Gets the name of this VolumeSnapshot.  # noqa: E501

        A non-modifiable, locally unique name chosen by the system.  # noqa: E501

        :return: The name of this VolumeSnapshot.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this VolumeSnapshot.

        A non-modifiable, locally unique name chosen by the system.  # noqa: E501

        :param name: The name of this VolumeSnapshot.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def arrays(self):
        """Gets the arrays of this VolumeSnapshot.  # noqa: E501

        The list of arrays where this resource exists. Many resources are on a single array, but some resources - for example pods - can be stretched across multiple arrays.  # noqa: E501

        :return: The arrays of this VolumeSnapshot.  # noqa: E501
        :rtype: list[FixedReference]
        """
        return self._arrays

    @arrays.setter
    def arrays(self, arrays):
        """Sets the arrays of this VolumeSnapshot.

        The list of arrays where this resource exists. Many resources are on a single array, but some resources - for example pods - can be stretched across multiple arrays.  # noqa: E501

        :param arrays: The arrays of this VolumeSnapshot.  # noqa: E501
        :type: list[FixedReference]
        """

        self._arrays = arrays

    @property
    def created(self):
        """Gets the created of this VolumeSnapshot.  # noqa: E501

        Creation time in milliseconds since UNIX epoch.  # noqa: E501

        :return: The created of this VolumeSnapshot.  # noqa: E501
        :rtype: int
        """
        return self._created

    @created.setter
    def created(self, created):
        """Sets the created of this VolumeSnapshot.

        Creation time in milliseconds since UNIX epoch.  # noqa: E501

        :param created: The created of this VolumeSnapshot.  # noqa: E501
        :type: int
        """

        self._created = created

    @property
    def destroyed(self):
        """Gets the destroyed of this VolumeSnapshot.  # noqa: E501

        Indicates if this snapshot has been destroyed and is pending eradication. Default is false.  # noqa: E501

        :return: The destroyed of this VolumeSnapshot.  # noqa: E501
        :rtype: bool
        """
        return self._destroyed

    @destroyed.setter
    def destroyed(self, destroyed):
        """Sets the destroyed of this VolumeSnapshot.

        Indicates if this snapshot has been destroyed and is pending eradication. Default is false.  # noqa: E501

        :param destroyed: The destroyed of this VolumeSnapshot.  # noqa: E501
        :type: bool
        """

        self._destroyed = destroyed

    @property
    def on(self):
        """Gets the on of this VolumeSnapshot.  # noqa: E501

        A reference to the array or the offload where the snapshot is stored.  # noqa: E501

        :return: The on of this VolumeSnapshot.  # noqa: E501
        :rtype: FixedReference
        """
        return self._on

    @on.setter
    def on(self, on):
        """Sets the on of this VolumeSnapshot.

        A reference to the array or the offload where the snapshot is stored.  # noqa: E501

        :param on: The on of this VolumeSnapshot.  # noqa: E501
        :type: FixedReference
        """

        self._on = on

    @property
    def pod(self):
        """Gets the pod of this VolumeSnapshot.  # noqa: E501


        :return: The pod of this VolumeSnapshot.  # noqa: E501
        :rtype: FixedReference
        """
        return self._pod

    @pod.setter
    def pod(self, pod):
        """Sets the pod of this VolumeSnapshot.


        :param pod: The pod of this VolumeSnapshot.  # noqa: E501
        :type: FixedReference
        """

        self._pod = pod

    @property
    def provisioned(self):
        """Gets the provisioned of this VolumeSnapshot.  # noqa: E501

        Indicates the size (in bytes) of the volume when the snapshot was taken.  # noqa: E501

        :return: The provisioned of this VolumeSnapshot.  # noqa: E501
        :rtype: int
        """
        return self._provisioned

    @provisioned.setter
    def provisioned(self, provisioned):
        """Sets the provisioned of this VolumeSnapshot.

        Indicates the size (in bytes) of the volume when the snapshot was taken.  # noqa: E501

        :param provisioned: The provisioned of this VolumeSnapshot.  # noqa: E501
        :type: int
        """

        self._provisioned = provisioned

    @property
    def serial(self):
        """Gets the serial of this VolumeSnapshot.  # noqa: E501

        Serial number generated by Purity when the snapshot was created.  # noqa: E501

        :return: The serial of this VolumeSnapshot.  # noqa: E501
        :rtype: str
        """
        return self._serial

    @serial.setter
    def serial(self, serial):
        """Sets the serial of this VolumeSnapshot.

        Serial number generated by Purity when the snapshot was created.  # noqa: E501

        :param serial: The serial of this VolumeSnapshot.  # noqa: E501
        :type: str
        """

        self._serial = serial

    @property
    def snapshot_group(self):
        """Gets the snapshot_group of this VolumeSnapshot.  # noqa: E501

        A reference to a consistency group snapshot that this snapshot is part of.  # noqa: E501

        :return: The snapshot_group of this VolumeSnapshot.  # noqa: E501
        :rtype: FixedReference
        """
        return self._snapshot_group

    @snapshot_group.setter
    def snapshot_group(self, snapshot_group):
        """Sets the snapshot_group of this VolumeSnapshot.

        A reference to a consistency group snapshot that this snapshot is part of.  # noqa: E501

        :param snapshot_group: The snapshot_group of this VolumeSnapshot.  # noqa: E501
        :type: FixedReference
        """

        self._snapshot_group = snapshot_group

    @property
    def source(self):
        """Gets the source of this VolumeSnapshot.  # noqa: E501

        A reference to the volume that the snapshot was taken from.  # noqa: E501

        :return: The source of this VolumeSnapshot.  # noqa: E501
        :rtype: FixedReference
        """
        return self._source

    @source.setter
    def source(self, source):
        """Sets the source of this VolumeSnapshot.

        A reference to the volume that the snapshot was taken from.  # noqa: E501

        :param source: The source of this VolumeSnapshot.  # noqa: E501
        :type: FixedReference
        """

        self._source = source

    @property
    def suffix(self):
        """Gets the suffix of this VolumeSnapshot.  # noqa: E501

        Suffix added to the source volume name used to generate the volume snapshot name.  # noqa: E501

        :return: The suffix of this VolumeSnapshot.  # noqa: E501
        :rtype: str
        """
        return self._suffix

    @suffix.setter
    def suffix(self, suffix):
        """Sets the suffix of this VolumeSnapshot.

        Suffix added to the source volume name used to generate the volume snapshot name.  # noqa: E501

        :param suffix: The suffix of this VolumeSnapshot.  # noqa: E501
        :type: str
        """

        self._suffix = suffix

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(VolumeSnapshot, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, VolumeSnapshot):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Pure1 Public REST API

    Pure1 Public REST API, developed by [Pure Storage, Inc.](http://www.purestorage.com/)  [Knowledge base reference documentation](https://support.purestorage.com/Pure1/Pure1_Manage/Pure1_Manage_-_REST_API/Pure1_Manage_-_REST_API__Reference)  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from pypureclient.pure1.api_client import ApiClient


class FileSystemSnapshotsApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def api10_file_system_snapshots_get(self, **kwargs):  # noqa: E501
        """api10_file_system_snapshots_get  # noqa: E501

        Get snapshots of file systems.   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api10_file_system_snapshots_get(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str authorization: REQUIRED normally; do not use if authenticating with the \"Try it out\" feature. Access JWT required to use any API endpoint.
        :param str x_request_id: Supplied by client during request or generated by server.
        :param str continuation_token: An opaque token used to iterate over a collection. The token to use on the next request is returned in the continuation_token field of the result. Single quotes are required around all strings.
        :param str filter: Exclude resources that don't match the specified criteria. Single quotes are required around all strings inside the filters.
        :param list[str] ids: A comma-separated list of resource IDs. If there is not at least one resource that matches each of the elements of names, an error is returned. Single quotes are required around all strings.
        :param int limit: Limit the size of the response to the specified number of resources. A limit of 0 can be used to get the number of resources without getting all of the resources. It will be returned in the total_item_count field. If a client asks for a page size larger than the maximum number, the request is still valid. In that case the server just returns the maximum number of items, disregarding the clients page size request. The default limit is 1000.
        :param list[str] names: A comma-separated list of resource names. If there is not at least one resource that matches each of the elements of names, an error is returned. Single quotes are required around all strings.
        :param int offset: The offset of the first resource to return from a collection.
        :param list[str] sort: Sort the response by the specified fields (in descending order if '-' is appended to the field name). If you provide a sort you will not get a continuation token in the response.
        :param list[str] source_ids: A comma-separated list of ids for the source of the object. If there is not at least one resource that matches each of the elements of names, an error is returned. Single quotes are required around all strings.
        :param list[str] source_names: A comma-separated list of names for the source of the object. If there is not at least one resource that matches each of the elements of names, an error is returned. Single quotes are required around all strings.
        :return: FileSystemSnapshotsGetResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.api10_file_system_snapshots_get_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.api10_file_system_snapshots_get_with_http_info(**kwargs)  # noqa: E501
            return data

    def api10_file_system_snapshots_get_with_http_info(self, **kwargs):  # noqa: E501
        """api10_file_system_snapshots_get  # noqa: E501

        Get snapshots of file systems.   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api10_file_system_snapshots_get_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str authorization: REQUIRED normally; do not use if authenticating with the \"Try it out\" feature. Access JWT required to use any API endpoint.
        :param str x_request_id: Supplied by client during request or generated by server.
        :param str continuation_token: An opaque token used to iterate over a collection. The token to use on the next request is returned in the continuation_token field of the result. Single quotes are required around all strings.
        :param str filter: Exclude resources that don't match the specified criteria. Single quotes are required around all strings inside the filters.
        :param list[str] ids: A comma-separated list of resource IDs. If there is not at least one resource that matches each of the elements of names, an error is returned. Single quotes are required around all strings.
        :param int limit: Limit the size of the response to the specified number of resources. A limit of 0 can be used to get the number of resources without getting all of the resources. It will be returned in the total_item_count field. If a client asks for a page size larger than the maximum number, the request is still valid. In that case the server just returns the maximum number of items, disregarding the clients page size request. The default limit is 1000.
        :param list[str] names: A comma-separated list of resource names. If there is not at least one resource that matches each of the elements of names, an error is returned. Single quotes are required around all strings.
        :param int offset: The offset of the first resource to return from a collection.
        :param list[str] sort: Sort the response by the specified fields (in descending order if '-' is appended to the field name). If you provide a sort you will not get a continuation token in the response.
        :param list[str] source_ids: A comma-separated list of ids for the source of the object. If there is not at least one resource that matches each of the elements of names, an error is returned. Single quotes are required around all strings.
        :param list[str] source_names: A comma-separated list of names for the source of the object. If there is not at least one resource that matches each of the elements of names, an error is returned. Single quotes are required around all strings.
        :return: FileSystemSnapshotsGetResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['authorization', 'x_request_id', 'continuation_token', 'filter', 'ids', 'limit', 'names', 'offset', 'sort', 'source_ids', 'source_names']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api10_file_system_snapshots_get" % key
                )
            params[key] = val
        del params['kwargs']

        if 'offset' in params and params['offset'] < 0:  # noqa: E501
            raise ValueError("Invalid value for parameter `offset` when calling `api10_file_system_snapshots_get`, must be a value greater than or equal to `0`")  # noqa: E501
        collection_formats = {}

        path_params = {}

        query_params = []
        if 'continuation_token' in params:
            query_params.append(('continuation_token', params['continuation_token']))  # noqa: E501
        if 'filter' in params:
            query_params.append(('filter', params['filter']))  # noqa: E501
        if 'ids' in params:
            query_params.append(('ids', params['ids']))  # noqa: E501
            collection_formats['ids'] = 'multi'  # noqa: E501
        if 'limit' in params:
            query_params.append(('limit', params['limit']))  # noqa: E501
        if 'names' in params:
            query_params.append(('names', params['names']))  # noqa: E501
            collection_formats['names'] = 'multi'  # noqa: E501
        if 'offset' in params:
            query_params.append(('offset', params['offset']))  # noqa: E501
        if 'sort' in params:
            query_params.append(('sort', params['sort']))  # noqa: E501
            collection_formats['sort'] = 'multi'  # noqa: E501
        if 'source_ids' in params:
            query_params.append(('source_ids', params['source_ids']))  # noqa: E501
            collection_formats['source_ids'] = 'multi'  # noqa: E501
        if 'source_names' in params:
            query_params.append(('source_names', params['source_names']))  # noqa: E501
            collection_formats['source_names'] = 'multi'  # noqa: E501

        header_params = {}
        if 'authorization' in params:
            header_params['Authorization'] = params['authorization']  # noqa: E501
        if 'x_request_id' in params:
            header_params['X-Request-ID'] = params['x_request_id']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['AuthorizationHeader']  # noqa: E501

        return self.api_client.call_api(
            '/api/1.0/file-system-snapshots', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='FileSystemSnapshotsGetResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

# flake8: noqa
"""
    Pure1 Public REST API

    Pure1 Public REST API, developed by [Pure Storage, Inc.](http://www.purestorage.com/)  [Knowledge base reference documentation](https://support.purestorage.com/Pure1/Pure1_Manage/Pure1_Manage_-_REST_API/Pure1_Manage_-_REST_API__Reference)  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

# import models into model package
from pypureclient.pure1.models.alert import Alert
from pypureclient.pure1.models.alerts import Alerts
from pypureclient.pure1.models.alerts_get import AlertsGet
from pypureclient.pure1.models.array import Array
from pypureclient.pure1.models.array_get_response import ArrayGetResponse
from pypureclient.pure1.models.array_response import ArrayResponse
from pypureclient.pure1.models.arrays import Arrays
from pypureclient.pure1.models.arrays_built_in import ArraysBuiltIn
from pypureclient.pure1.models.arrays_resource import ArraysResource
from pypureclient.pure1.models.audit import Audit
from pypureclient.pure1.models.audits import Audits
from pypureclient.pure1.models.audits_get import AuditsGet
from pypureclient.pure1.models.built_in_as_of import BuiltInAsOf
from pypureclient.pure1.models.file_system import FileSystem
from pypureclient.pure1.models.file_system_snapshot import FileSystemSnapshot
from pypureclient.pure1.models.file_system_snapshots import FileSystemSnapshots
from pypureclient.pure1.models.file_system_snapshots_get_response import FileSystemSnapshotsGetResponse
from pypureclient.pure1.models.file_system_snapshots_response import FileSystemSnapshotsResponse
from pypureclient.pure1.models.file_systems import FileSystems
from pypureclient.pure1.models.file_systems_get_response import FileSystemsGetResponse
from pypureclient.pure1.models.file_systems_response import FileSystemsResponse
from pypureclient.pure1.models.fixed_reference import FixedReference
from pypureclient.pure1.models.http import Http
from pypureclient.pure1.models.metric import Metric
from pypureclient.pure1.models.metric_availability import MetricAvailability
from pypureclient.pure1.models.metric_get_response import MetricGetResponse
from pypureclient.pure1.models.metric_history import MetricHistory
from pypureclient.pure1.models.metric_history_get_response import MetricHistoryGetResponse
from pypureclient.pure1.models.metric_history_response import MetricHistoryResponse
from pypureclient.pure1.models.metric_response import MetricResponse
from pypureclient.pure1.models.network_interface import NetworkInterface
from pypureclient.pure1.models.network_interface_get_response import NetworkInterfaceGetResponse
from pypureclient.pure1.models.network_interface_response import NetworkInterfaceResponse
from pypureclient.pure1.models.nfs import Nfs
from pypureclient.pure1.models.page_info import PageInfo
from pypureclient.pure1.models.pod import Pod
from pypureclient.pure1.models.pod_array_status import PodArrayStatus
from pypureclient.pure1.models.pod_get_response import PodGetResponse
from pypureclient.pure1.models.pod_response import PodResponse
from pypureclient.pure1.models.resource import Resource
from pypureclient.pure1.models.smb import Smb
from pypureclient.pure1.models.tag import Tag
from pypureclient.pure1.models.tag1 import Tag1
from pypureclient.pure1.models.tag_get_response import TagGetResponse
from pypureclient.pure1.models.tag_response import TagResponse
from pypureclient.pure1.models.time_aware import TimeAware
from pypureclient.pure1.models.volume import Volume
from pypureclient.pure1.models.volume_get_response import VolumeGetResponse
from pypureclient.pure1.models.volume_response import VolumeResponse
from pypureclient.pure1.models.volume_snapshot import VolumeSnapshot
from pypureclient.pure1.models.volume_snapshots import VolumeSnapshots
from pypureclient.pure1.models.volume_snapshots_get_response import VolumeSnapshotsGetResponse
from pypureclient.pure1.models.volume_snapshots_response import VolumeSnapshotsResponse



# coding: utf-8

"""
    Pure1 Public REST API

    Pure1 Public REST API, developed by [Pure Storage, Inc.](http://www.purestorage.com/)  [Knowledge base reference documentation](https://support.purestorage.com/Pure1/Pure1_Manage/Pure1_Manage_-_REST_API/Pure1_Manage_-_REST_API__Reference)  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from pypureclient.pure1.models.built_in_as_of import BuiltInAsOf  # noqa: F401,E501
from pypureclient.pure1.models.metric_availability import MetricAvailability  # noqa: F401,E501


class Metric(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'as_of': 'int',
        'id': 'str',
        'name': 'str',
        'availabilities': 'list[MetricAvailability]',
        'description': 'str',
        'resource_types': 'list[str]',
        'unit': 'str'
    }

    attribute_map = {
        'as_of': '_as_of',
        'id': 'id',
        'name': 'name',
        'availabilities': 'availabilities',
        'description': 'description',
        'resource_types': 'resource_types',
        'unit': 'unit'
    }

    def __init__(self, as_of=None, id=None, name=None, availabilities=None, description=None, resource_types=None, unit=None):  # noqa: E501
        """Metric - a model defined in Swagger"""  # noqa: E501

        self._as_of = None
        self._id = None
        self._name = None
        self._availabilities = None
        self._description = None
        self._resource_types = None
        self._unit = None
        self.discriminator = None

        self.as_of = as_of
        self.id = id
        self.name = name
        self.availabilities = availabilities
        self.description = description
        self.resource_types = resource_types
        self.unit = unit

    @property
    def as_of(self):
        """Gets the as_of of this Metric.  # noqa: E501

        The freshness of the data (timestamp in millis since epoch)  # noqa: E501

        :return: The as_of of this Metric.  # noqa: E501
        :rtype: int
        """
        return self._as_of

    @as_of.setter
    def as_of(self, as_of):
        """Sets the as_of of this Metric.

        The freshness of the data (timestamp in millis since epoch)  # noqa: E501

        :param as_of: The as_of of this Metric.  # noqa: E501
        :type: int
        """
        if as_of is None:
            raise ValueError("Invalid value for `as_of`, must not be `None`")  # noqa: E501

        self._as_of = as_of

    @property
    def id(self):
        """Gets the id of this Metric.  # noqa: E501

        A non-modifiable, globally unique ID chosen by the system.  # noqa: E501

        :return: The id of this Metric.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this Metric.

        A non-modifiable, globally unique ID chosen by the system.  # noqa: E501

        :param id: The id of this Metric.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def name(self):
        """Gets the name of this Metric.  # noqa: E501

        A non-modifiable, locally unique name chosen by the system.  # noqa: E501

        :return: The name of this Metric.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this Metric.

        A non-modifiable, locally unique name chosen by the system.  # noqa: E501

        :param name: The name of this Metric.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def availabilities(self):
        """Gets the availabilities of this Metric.  # noqa: E501

        The available resolutions, aggregations and retentions of this metric  # noqa: E501

        :return: The availabilities of this Metric.  # noqa: E501
        :rtype: list[MetricAvailability]
        """
        return self._availabilities

    @availabilities.setter
    def availabilities(self, availabilities):
        """Sets the availabilities of this Metric.

        The available resolutions, aggregations and retentions of this metric  # noqa: E501

        :param availabilities: The availabilities of this Metric.  # noqa: E501
        :type: list[MetricAvailability]
        """

        self._availabilities = availabilities

    @property
    def description(self):
        """Gets the description of this Metric.  # noqa: E501

        The additional description for the the metric  # noqa: E501

        :return: The description of this Metric.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this Metric.

        The additional description for the the metric  # noqa: E501

        :param description: The description of this Metric.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def resource_types(self):
        """Gets the resource_types of this Metric.  # noqa: E501

        The type of resource (as described by their endpoints) that this metric is available at. NOTE that a metric could be available for a combination of resource types, e.g. mirrored writes from \"arrays\" to \"pods\".  # noqa: E501

        :return: The resource_types of this Metric.  # noqa: E501
        :rtype: list[str]
        """
        return self._resource_types

    @resource_types.setter
    def resource_types(self, resource_types):
        """Sets the resource_types of this Metric.

        The type of resource (as described by their endpoints) that this metric is available at. NOTE that a metric could be available for a combination of resource types, e.g. mirrored writes from \"arrays\" to \"pods\".  # noqa: E501

        :param resource_types: The resource_types of this Metric.  # noqa: E501
        :type: list[str]
        """

        self._resource_types = resource_types

    @property
    def unit(self):
        """Gets the unit of this Metric.  # noqa: E501

        The unit of the metric  # noqa: E501

        :return: The unit of this Metric.  # noqa: E501
        :rtype: str
        """
        return self._unit

    @unit.setter
    def unit(self, unit):
        """Sets the unit of this Metric.

        The unit of the metric  # noqa: E501

        :param unit: The unit of this Metric.  # noqa: E501
        :type: str
        """

        self._unit = unit

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Metric, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Metric):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Pure1 Public REST API

    Pure1 Public REST API, developed by [Pure Storage, Inc.](http://www.purestorage.com/)  [Knowledge base reference documentation](https://support.purestorage.com/Pure1/Pure1_Manage/Pure1_Manage_-_REST_API/Pure1_Manage_-_REST_API__Reference)  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from pypureclient.pure1.models.metric import Metric  # noqa: F401,E501
from pypureclient.pure1.models.page_info import PageInfo  # noqa: F401,E501


class MetricGetResponse(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'continuation_token': 'str',
        'total_item_count': 'int',
        'items': 'list[Metric]'
    }

    attribute_map = {
        'continuation_token': 'continuation_token',
        'total_item_count': 'total_item_count',
        'items': 'items'
    }

    def __init__(self, continuation_token=None, total_item_count=None, items=None):  # noqa: E501
        """MetricGetResponse - a model defined in Swagger"""  # noqa: E501

        self._continuation_token = None
        self._total_item_count = None
        self._items = None
        self.discriminator = None

        self.continuation_token = continuation_token
        self.total_item_count = total_item_count
        self.items = items

    @property
    def continuation_token(self):
        """Gets the continuation_token of this MetricGetResponse.  # noqa: E501

        Continuation token that can be provided in the continuation_token query param to get the next page of data. If you use the continuation token to page through data you are guaranteed to get all items exactly once regardless of how items are modified. If an item is added or deleted during the pagination then it may or may not be returned. The continuation token is generated if the limit is less than the remaining number of items, and the default sort is used (no sort is specified).  # noqa: E501

        :return: The continuation_token of this MetricGetResponse.  # noqa: E501
        :rtype: str
        """
        return self._continuation_token

    @continuation_token.setter
    def continuation_token(self, continuation_token):
        """Sets the continuation_token of this MetricGetResponse.

        Continuation token that can be provided in the continuation_token query param to get the next page of data. If you use the continuation token to page through data you are guaranteed to get all items exactly once regardless of how items are modified. If an item is added or deleted during the pagination then it may or may not be returned. The continuation token is generated if the limit is less than the remaining number of items, and the default sort is used (no sort is specified).  # noqa: E501

        :param continuation_token: The continuation_token of this MetricGetResponse.  # noqa: E501
        :type: str
        """

        self._continuation_token = continuation_token

    @property
    def total_item_count(self):
        """Gets the total_item_count of this MetricGetResponse.  # noqa: E501

        total number of items after applying filter params  # noqa: E501

        :return: The total_item_count of this MetricGetResponse.  # noqa: E501
        :rtype: int
        """
        return self._total_item_count

    @total_item_count.setter
    def total_item_count(self, total_item_count):
        """Sets the total_item_count of this MetricGetResponse.

        total number of items after applying filter params  # noqa: E501

        :param total_item_count: The total_item_count of this MetricGetResponse.  # noqa: E501
        :type: int
        """

        self._total_item_count = total_item_count

    @property
    def items(self):
        """Gets the items of this MetricGetResponse.  # noqa: E501


        :return: The items of this MetricGetResponse.  # noqa: E501
        :rtype: list[Metric]
        """
        return self._items

    @items.setter
    def items(self, items):
        """Sets the items of this MetricGetResponse.


        :param items: The items of this MetricGetResponse.  # noqa: E501
        :type: list[Metric]
        """

        self._items = items

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(MetricGetResponse, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, MetricGetResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Pure1 Public REST API

    Pure1 Public REST API, developed by [Pure Storage, Inc.](http://www.purestorage.com/)  [Knowledge base reference documentation](https://support.purestorage.com/Pure1/Pure1_Manage/Pure1_Manage_-_REST_API/Pure1_Manage_-_REST_API__Reference)  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from pypureclient.pure1.models.arrays_built_in import ArraysBuiltIn  # noqa: F401,E501
from pypureclient.pure1.models.fixed_reference import FixedReference  # noqa: F401,E501
from pypureclient.pure1.models.http import Http  # noqa: F401,E501
from pypureclient.pure1.models.nfs import Nfs  # noqa: F401,E501
from pypureclient.pure1.models.smb import Smb  # noqa: F401,E501


class FileSystems(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'as_of': 'int',
        'id': 'str',
        'name': 'str',
        'arrays': 'list[FixedReference]',
        'created': 'int',
        'destroyed': 'bool',
        'fast_remove_directory_enabled': 'bool',
        'hard_limit_enabled': 'bool',
        'http': 'Http',
        'nfs': 'Nfs',
        'provisioned': 'int',
        'smb': 'Smb',
        'snapshot_directory_enabled': 'bool'
    }

    attribute_map = {
        'as_of': '_as_of',
        'id': 'id',
        'name': 'name',
        'arrays': 'arrays',
        'created': 'created',
        'destroyed': 'destroyed',
        'fast_remove_directory_enabled': 'fast_remove_directory_enabled',
        'hard_limit_enabled': 'hard_limit_enabled',
        'http': 'http',
        'nfs': 'nfs',
        'provisioned': 'provisioned',
        'smb': 'smb',
        'snapshot_directory_enabled': 'snapshot_directory_enabled'
    }

    def __init__(self, as_of=None, id=None, name=None, arrays=None, created=None, destroyed=None, fast_remove_directory_enabled=None, hard_limit_enabled=None, http=None, nfs=None, provisioned=None, smb=None, snapshot_directory_enabled=None):  # noqa: E501
        """FileSystems - a model defined in Swagger"""  # noqa: E501

        self._as_of = None
        self._id = None
        self._name = None
        self._arrays = None
        self._created = None
        self._destroyed = None
        self._fast_remove_directory_enabled = None
        self._hard_limit_enabled = None
        self._http = None
        self._nfs = None
        self._provisioned = None
        self._smb = None
        self._snapshot_directory_enabled = None
        self.discriminator = None

        self.as_of = as_of
        self.id = id
        self.name = name
        self.arrays = arrays
        self.created = created
        self.destroyed = destroyed
        self.fast_remove_directory_enabled = fast_remove_directory_enabled
        self.hard_limit_enabled = hard_limit_enabled
        self.http = http
        self.nfs = nfs
        self.provisioned = provisioned
        self.smb = smb
        self.snapshot_directory_enabled = snapshot_directory_enabled

    @property
    def as_of(self):
        """Gets the as_of of this FileSystems.  # noqa: E501

        The freshness of the data (timestamp in millis since epoch)  # noqa: E501

        :return: The as_of of this FileSystems.  # noqa: E501
        :rtype: int
        """
        return self._as_of

    @as_of.setter
    def as_of(self, as_of):
        """Sets the as_of of this FileSystems.

        The freshness of the data (timestamp in millis since epoch)  # noqa: E501

        :param as_of: The as_of of this FileSystems.  # noqa: E501
        :type: int
        """
        if as_of is None:
            raise ValueError("Invalid value for `as_of`, must not be `None`")  # noqa: E501

        self._as_of = as_of

    @property
    def id(self):
        """Gets the id of this FileSystems.  # noqa: E501

        A non-modifiable, globally unique ID chosen by the system.  # noqa: E501

        :return: The id of this FileSystems.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this FileSystems.

        A non-modifiable, globally unique ID chosen by the system.  # noqa: E501

        :param id: The id of this FileSystems.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def name(self):
        """Gets the name of this FileSystems.  # noqa: E501

        A non-modifiable, locally unique name chosen by the system.  # noqa: E501

        :return: The name of this FileSystems.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this FileSystems.

        A non-modifiable, locally unique name chosen by the system.  # noqa: E501

        :param name: The name of this FileSystems.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def arrays(self):
        """Gets the arrays of this FileSystems.  # noqa: E501

        The list of arrays where this resource exists. Many resources are on a single array, but some resources - for example pods - can be stretched across multiple arrays.  # noqa: E501

        :return: The arrays of this FileSystems.  # noqa: E501
        :rtype: list[FixedReference]
        """
        return self._arrays

    @arrays.setter
    def arrays(self, arrays):
        """Sets the arrays of this FileSystems.

        The list of arrays where this resource exists. Many resources are on a single array, but some resources - for example pods - can be stretched across multiple arrays.  # noqa: E501

        :param arrays: The arrays of this FileSystems.  # noqa: E501
        :type: list[FixedReference]
        """

        self._arrays = arrays

    @property
    def created(self):
        """Gets the created of this FileSystems.  # noqa: E501

        Creation time in milliseconds since UNIX epoch.  # noqa: E501

        :return: The created of this FileSystems.  # noqa: E501
        :rtype: int
        """
        return self._created

    @created.setter
    def created(self, created):
        """Sets the created of this FileSystems.

        Creation time in milliseconds since UNIX epoch.  # noqa: E501

        :param created: The created of this FileSystems.  # noqa: E501
        :type: int
        """

        self._created = created

    @property
    def destroyed(self):
        """Gets the destroyed of this FileSystems.  # noqa: E501

        Is the file system destroyed? Default is false. Modifiable.  # noqa: E501

        :return: The destroyed of this FileSystems.  # noqa: E501
        :rtype: bool
        """
        return self._destroyed

    @destroyed.setter
    def destroyed(self, destroyed):
        """Sets the destroyed of this FileSystems.

        Is the file system destroyed? Default is false. Modifiable.  # noqa: E501

        :param destroyed: The destroyed of this FileSystems.  # noqa: E501
        :type: bool
        """

        self._destroyed = destroyed

    @property
    def fast_remove_directory_enabled(self):
        """Gets the fast_remove_directory_enabled of this FileSystems.  # noqa: E501

        Is fast remove directory enabled? Default is false. Modifiable.  # noqa: E501

        :return: The fast_remove_directory_enabled of this FileSystems.  # noqa: E501
        :rtype: bool
        """
        return self._fast_remove_directory_enabled

    @fast_remove_directory_enabled.setter
    def fast_remove_directory_enabled(self, fast_remove_directory_enabled):
        """Sets the fast_remove_directory_enabled of this FileSystems.

        Is fast remove directory enabled? Default is false. Modifiable.  # noqa: E501

        :param fast_remove_directory_enabled: The fast_remove_directory_enabled of this FileSystems.  # noqa: E501
        :type: bool
        """

        self._fast_remove_directory_enabled = fast_remove_directory_enabled

    @property
    def hard_limit_enabled(self):
        """Gets the hard_limit_enabled of this FileSystems.  # noqa: E501

        Is the file system's size a hard limit quota? Default is false.  # noqa: E501

        :return: The hard_limit_enabled of this FileSystems.  # noqa: E501
        :rtype: bool
        """
        return self._hard_limit_enabled

    @hard_limit_enabled.setter
    def hard_limit_enabled(self, hard_limit_enabled):
        """Sets the hard_limit_enabled of this FileSystems.

        Is the file system's size a hard limit quota? Default is false.  # noqa: E501

        :param hard_limit_enabled: The hard_limit_enabled of this FileSystems.  # noqa: E501
        :type: bool
        """

        self._hard_limit_enabled = hard_limit_enabled

    @property
    def http(self):
        """Gets the http of this FileSystems.  # noqa: E501

        HTTP configuration. Modifiable.  # noqa: E501

        :return: The http of this FileSystems.  # noqa: E501
        :rtype: Http
        """
        return self._http

    @http.setter
    def http(self, http):
        """Sets the http of this FileSystems.

        HTTP configuration. Modifiable.  # noqa: E501

        :param http: The http of this FileSystems.  # noqa: E501
        :type: Http
        """

        self._http = http

    @property
    def nfs(self):
        """Gets the nfs of this FileSystems.  # noqa: E501

        NFS configuration. Modifiable.  # noqa: E501

        :return: The nfs of this FileSystems.  # noqa: E501
        :rtype: Nfs
        """
        return self._nfs

    @nfs.setter
    def nfs(self, nfs):
        """Sets the nfs of this FileSystems.

        NFS configuration. Modifiable.  # noqa: E501

        :param nfs: The nfs of this FileSystems.  # noqa: E501
        :type: Nfs
        """

        self._nfs = nfs

    @property
    def provisioned(self):
        """Gets the provisioned of this FileSystems.  # noqa: E501

        The provisioned size of the file system in bytes. Modifiable. Default is 0, meaning unlimited.  # noqa: E501

        :return: The provisioned of this FileSystems.  # noqa: E501
        :rtype: int
        """
        return self._provisioned

    @provisioned.setter
    def provisioned(self, provisioned):
        """Sets the provisioned of this FileSystems.

        The provisioned size of the file system in bytes. Modifiable. Default is 0, meaning unlimited.  # noqa: E501

        :param provisioned: The provisioned of this FileSystems.  # noqa: E501
        :type: int
        """

        self._provisioned = provisioned

    @property
    def smb(self):
        """Gets the smb of this FileSystems.  # noqa: E501

        SMB configuration. Modifiable.  # noqa: E501

        :return: The smb of this FileSystems.  # noqa: E501
        :rtype: Smb
        """
        return self._smb

    @smb.setter
    def smb(self, smb):
        """Sets the smb of this FileSystems.

        SMB configuration. Modifiable.  # noqa: E501

        :param smb: The smb of this FileSystems.  # noqa: E501
        :type: Smb
        """

        self._smb = smb

    @property
    def snapshot_directory_enabled(self):
        """Gets the snapshot_directory_enabled of this FileSystems.  # noqa: E501

        Is snapshot directory enabled? Default is false. Modifiable.  # noqa: E501

        :return: The snapshot_directory_enabled of this FileSystems.  # noqa: E501
        :rtype: bool
        """
        return self._snapshot_directory_enabled

    @snapshot_directory_enabled.setter
    def snapshot_directory_enabled(self, snapshot_directory_enabled):
        """Sets the snapshot_directory_enabled of this FileSystems.

        Is snapshot directory enabled? Default is false. Modifiable.  # noqa: E501

        :param snapshot_directory_enabled: The snapshot_directory_enabled of this FileSystems.  # noqa: E501
        :type: bool
        """

        self._snapshot_directory_enabled = snapshot_directory_enabled

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(FileSystems, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, FileSystems):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



class Parameters(object):
    '''
    A class for static parameter names.
    '''
    aggregation = 'aggregation'
    authorization = 'authorization'
    continuation_token = 'continuation_token'
    end_time = 'end_time'
    filter = 'filter'
    ids = 'ids'
    keys = 'keys'
    limit = 'limit'
    names = 'names'
    namespaces = 'namespaces'
    offset = 'offset'
    references = 'references'
    resolution = 'resolution'
    resources = 'resources'
    resource_ids = 'resource_ids'
    resource_names = 'resource_names'
    resource_types = 'resource_types'
    sort = 'sort'
    source_ids = 'source_ids'
    source_names = 'source_names'
    start_time = 'start_time'
    tag = 'tag'
    x_request_id = 'x_request_id'

    @staticmethod
    def get_str_parameters():
        '''
        Get parameters that are expected to be quoted strings.

        Returns:
            list[str]
        '''
        return [Parameters.aggregation, Parameters.continuation_token]

    @staticmethod
    def get_list_parameters():
        '''
        Get parameters that are expected to be a list of unquoted strings.

        Returns:
            list[str]
        '''
        return [Parameters.sort]

    @staticmethod
    def get_list_str_parameters():
        '''
        Get parameters that are expected to be a list of quoted strings.

        Returns:
            list[str]
        '''
        return [Parameters.ids, Parameters.names, Parameters.keys,
                Parameters.namespaces, Parameters.resource_types,
                Parameters.resource_ids, Parameters.resource_names,
                Parameters.source_ids, Parameters.source_names]


class Headers(object):
    '''
    A class for static header names.
    '''
    authorization = 'Authorization'
    x_request_id = 'X-Request-ID'
    x_ratelimit_sec = 'X-RateLimit-Limit-second'
    x_ratelimit_min = 'X-RateLimit-Limit-minute'
    x_ratelimit_remaining_sec = 'X-RateLimit-Remaining-second'
    x_ratelimit_remaining_min = 'X-RateLimit-Remaining-minute'


class Responses(object):
    '''
    A class for static response names.
    '''
    context = 'context'
    errors = 'errors'
    message = 'message'
